#[macro_use]
extern crate rocket;

use poise::serenity_prelude::Http;
use rocket::fs::{relative, FileServer};
use rocket_dyn_templates::Template;
use sass_rocket_fairing::SassFairing;
use std::env;

mod models;
use models::Settings;

mod utils;

mod cookies;

mod routes;
use routes::*;

mod prelude;

#[launch]
async fn rocket() -> _ {
    dotenv::dotenv().expect("Failed to load .env file");

    let token = env::var("DISCORD_TOKEN").expect("Expected a token in the environment");
    let http = Http::new(&token);

    let config = rocket::Config::figment().merge(("port", 1313)).merge((
        "secret_key",
        env::var("SECRET")
            .expect("Must have SECRET defined in .env for private cookie persistence"),
    ));

    rocket::custom(config)
        .manage(Settings::new(&http).await.unwrap())
        .manage(http)
        .mount(
            "/",
            routes![get_challenge, login, post_login, success, logout, testing],
        )
        .mount("/css", FileServer::from(relative!("styles/css")))
        .attach(Template::fairing())
        .attach(SassFairing::default())
}
